@@ -49,18 +49,20 @@ logo <- grid::rasterGrob(logo,interpolate = TRUE)
 
 g=ggplot2::ggplot(df, aes(x = log(.data$Rank), y = .data$Freq, text=paste("Source: ",.data$SO,"\nN. of Documents: ",.data$Freq))) +
   geom_line(aes(group="NA")) +
-  geom_area(aes(group="NA"),fill = "dodgerblue", alpha = 0.5) +
-  annotate("rect", xmin=0, xmax=log(df$Rank[a]), ymin=0, ymax=max(df$Freq), alpha=0.4)+
+  geom_area(aes(group="NA"),fill = "gray90", alpha = 0.5) +
+  annotate("rect", xmin=0, xmax=log(df$Rank[a]), ymin=0, ymax=max(df$Freq), alpha=0.2)+
   labs(x = 'Source log(Rank)', y = 'Articles', title = "Bradford's Law") +
   annotate("text",x=log(df$Rank[a])/2, y=max(df$Freq)/2, label = "Core\nSources",fontface =2,alpha=0.5,size=10)+
   scale_x_continuous(breaks=log(df$Rank)[1:a],labels=as.character(substr(df$SO,1,25))[1:a]) +
   theme(text = element_text(color = "#444444")
         ,legend.position="none"
-        ,panel.background = element_rect(fill = '#EFEFEF')
-        ,panel.grid.minor = element_line(color = '#FFFFFF')
-        ,panel.grid.major = element_line(color = '#FFFFFF')
+        ,panel.background = element_rect(fill = '#FFFFFF')
+        ,panel.grid.minor = element_blank()
+        ,panel.grid.major = element_blank()
         ,plot.title = element_text(size = 24)
         ,axis.title = element_text(size = 14, color = '#555555')
+        ,axis.line.x = element_line(color="black",size=0.5)
+        ,axis.line.y = element_line(color="black",size=0.5)
         ,axis.title.y = element_text(vjust = 1, angle = 90)
         ,axis.title.x = element_text(hjust = 0)
         ,axis.text.x = element_text(angle=90,hjust=1,size=8,face="bold")
