@@ -23,10 +23,12 @@
 #'
 #'
 #' @examples
+#' 
+#' \dontrun{
 #' data(management, package = "bibliometrixData")
 #'
 #' histResults <- histNetwork(management, min.citations = 0, sep = ";")
-#'
+#' }
 #'
 #' @seealso \code{\link{convert2df}} to import and convert an ISI or SCOPUS
 #'   Export file in a bibliographic data frame.
@@ -124,8 +126,8 @@ wos <- function(M, min.citations, sep, network, verbose){
   M[LCS$nLABEL, "LCS"] <- LCS$n
   M_orig$LCS <- M$LCS
   
-  histData <- M[c("LABEL","TI","DI","PY","LCS","TC")]
-  names(histData) <- c("Paper","Title", "DOI","Year","LCS","GCS")
+  histData <- M[c("LABEL","TI","DE","ID","DI","PY","LCS","TC")]
+  names(histData) <- c("Paper","Title","Author_Keywords","KeywordsPlus", "DOI","Year","LCS","GCS")
   
   if (isTRUE(network)){
     # Citing data frame
